@@ -15,7 +15,6 @@ class ImageLoaderDDS(ImageLoaderBase):
         return ('dds', )
 
     def load(self, filename):
-        Logger.debug('Image: Load <%s>' % filename)
         try:
             dds = DDSFile(filename=filename)
         except:
@@ -32,7 +31,7 @@ class ImageLoaderDDS(ImageLoaderBase):
                 w, h = images_size[index]
                 data = images[index]
                 im.add_mipmap(index, w, h, data)
-        return im
+        return [im]
 
 # register
 ImageLoader.register(ImageLoaderDDS)
