@@ -4,7 +4,7 @@ FileChooser
 
 .. versionadded:: 1.0.5
 
-.. warning:
+.. warning::
 
     This is experimental and subject to change as long as this warning notice is
     present.
@@ -48,7 +48,7 @@ def is_hidden_win(fn):
         return False
     try:
         return GetFileAttributesEx(fn)[0] & FILE_ATTRIBUTE_HIDDEN
-    except error, e:
+    except error:
         # This error can occured when a file is already accessed by someone
         # else. So don't return to True, because we have lot of chances to not
         # being able to do anything with it.
@@ -62,6 +62,10 @@ def alphanumeric_folders_first(files):
 
 
 class FileChooserController(FloatLayout):
+    '''Base for implementing a FileChooser. Don't use that class directly,
+    prefer to use one implementation like :class:`FileChooserListView` or
+    :class:`FileChooserIconView`.
+    '''
     _ENTRY_TEMPLATE = None
 
     path = StringProperty(u'/')
@@ -73,17 +77,20 @@ class FileChooserController(FloatLayout):
 
     filters = ListProperty([])
     '''
-    :class:`~kivy.properties.ListProperty`, defaults to [], equal to '*'.
+    :class:`~kivy.properties.ListProperty`, defaults to [], equal to '\*'.
     The filters to be applied to the files in the directory, e.g. ['*.png'].
     The filters are not reset when the path changes, you need to do that
     yourself if you want that. You can use the following patterns:
 
-      Pattern	| Meaning
-      ----------+---------------------------------
-      *	        | matches everything
-      ?	        | matches any single character
-      [seq]	| matches any character in seq
-      [!seq]	| matches any character not in seq
+      ========== =================================
+      Pattern     Meaning
+      ========== =================================
+      \*         matches everything
+      ?          matches any single character
+      [seq]      matches any character in seq
+      [!seq]     matches any character not in seq
+      ========== =================================
+
     '''
 
     filter_dirs = BooleanProperty(False)
@@ -176,6 +183,7 @@ class FileChooserController(FloatLayout):
             if isdir(entry.path):
                 self.open_entry(entry)
             else:
+                self.selection = [entry.path, ]
                 self.dispatch('on_submit', [entry.path], touch)
 
     def open_entry(self, entry):
@@ -242,7 +250,7 @@ class FileChooserController(FloatLayout):
             self.dispatch('on_entry_added', pardir)
         try:
             self._add_files(self.path)
-        except OSError, e:
+        except OSError:
             Logger.exception('Unable to open directory <%s>' % self.path)
 
     def _add_files(self, path, parent=None):
@@ -262,17 +270,17 @@ class FileChooserController(FloatLayout):
         is_hidden = self.is_hidden
         if not self.show_hidden:
             files = [x for x in files if not is_hidden(x)]
-        for file in files:
+        for fn in files:
 
             def get_nice_size():
                 # Use a closure for lazy-loading here
-                return self.get_nice_size(file)
+                return self.get_nice_size(fn)
 
-            ctx = {'name': basename(file),
+            ctx = {'name': basename(fn),
                    'get_nice_size': get_nice_size,
-                   'path': file,
+                   'path': fn,
                    'controller': self,
-                   'isdir': isdir(file),
+                   'isdir': isdir(fn),
                    'parent': parent,
                    'sep': sep}
             entry = Builder.template(self._ENTRY_TEMPLATE, **ctx)
@@ -303,10 +311,14 @@ class FileChooserController(FloatLayout):
 
 
 class FileChooserListView(FileChooserController):
+    '''Implementation of :class:`FileChooserController` using a list view
+    '''
     _ENTRY_TEMPLATE = 'FileListEntry'
 
 
 class FileChooserIconView(FileChooserController):
+    '''Implementation of :class:`FileChooserController` using an icon view
+    '''
     _ENTRY_TEMPLATE = 'FileIconEntry'
 
 
@@ -319,6 +331,6 @@ if __name__ == '__main__':
             pos = (100, 100)
             size_hint = (None, None)
             size = (300, 400)
-            #return FileChooserListView(pos=pos, size=size, size_hint=size_hint)
+            return FileChooserListView(pos=pos, size=size, size_hint=size_hint)
             return FileChooserIconView(pos=pos, size=size, size_hint=size_hint)
     FileChooserApp().run()
