@@ -2,17 +2,19 @@
 Video
 =====
 
-You can play video files using Video widget. Depending of your Video core
-provider, you may be able to play differents formats. For example, pygame video
-provider allow only MPEG1 on Linux and OSX. GStreamer is more versatile, and can
-play many other video format, as MKV, OGV, AVI, MOV, FLV... depending of the
-gstreamer plugins installed.
+The :class:`Video` widget is used to display video files and streams. Depending
+on your Video core provider, platform and plugins you will be able to play
+different formats. For example, pygame video provider only supports MPEG1 on
+Linux and OSX. GStreamer is more versatile, and can read many video containers
+and codecs such as MKV, OGV, AVI, MOV, FLV (if the correct gstreamer plugins
+are installed). Our :class:`~kivy.core.video.VideoBase` implementation is used
+under the hood.
 
-The video loading is also asynchronous. Many properties are not available until
-the video is loaded. The video is loaded when the texture is created. ::
+The video loading is asynchronous - many properties are not available until
+the video is loaded (when the texture is created). ::
 
     def on_position_change(instance, value):
-        print 'The initial position in the video is', value
+        print 'The position in the video is', value
     def on_duration_change(instance, value):
         print 'The duration of the video is', video
     video = Video(source='PandaSneezes.avi')
@@ -31,14 +33,14 @@ from kivy.properties import BooleanProperty, NumericProperty, ObjectProperty
 
 
 class Video(Image):
-    '''Video class. See module documentation for more informations.
+    '''Video class. See module documentation for more information.
     '''
 
     play = BooleanProperty(False)
-    '''Boolean indicate if the video is playing.
+    '''Boolean, indicates if the video is playing.
     You can start/stop the video by setting this property. ::
 
-        # start the video playing at creation
+        # start playing the video at creation
         video = Video(source='movie.mkv', play=True)
 
         # create the video, and start later
@@ -51,7 +53,7 @@ class Video(Image):
     '''
 
     eos = BooleanProperty(False)
-    '''Boolean indicate if the video is done playing through the end.
+    '''Boolean, indicates if the video is done playing (reached end of stream).
 
     :data:`eos` is a :class:`~kivy.properties.BooleanProperty`, default to
     False.
@@ -109,7 +111,11 @@ class Video(Image):
             self._video = None
             self.texture = None
         else:
-            filename = resource_find(self.source)
+            filename = self.source
+            # FIXME make it extensible.
+            if filename.split(':')[0] not in (
+                    'http', 'https', 'file', 'udp', 'rtp', 'rtsp'):
+                filename = resource_find(filename)
             self._video = CoreVideo(filename=filename, **self.options)
             self._video.bind(on_load=self._on_video_frame,
                              on_frame=self._on_video_frame,
@@ -127,6 +133,7 @@ class Video(Image):
                 self._video.stop()
                 self._video.position = 0.
                 self._video.eos = False
+            self.eos = False
             self._video.play()
         else:
             self._video.stop()
@@ -138,6 +145,7 @@ class Video(Image):
         self.canvas.ask_update()
 
     def _on_eos(self, *largs):
+        self.play = False
         self.eos = True
 
     def on_volume(self, instance, value):
